#-------------------------------------------------------------------------------
import pygame
import config
from pygame.locals import *

DEBUG_ENABLE = False

#-------------------------------------------------------------------------------
class Console:
    MAX_LINES = 30
    COLOR = (100,255,100)
    VAR_COLOR = (255,255,255)

    #---------------------------------------------------------------------------
    def init( self, screen ):
        self.screen = screen
        self.font = pygame.font.SysFont( 'Monospace', 16 )
        self.lines = []
        self.lineSize = self.font.get_linesize() * 1.2
        self.m_y = 10

    #---------------------------------------------------------------------------
    def printMsg( self, msg ):
        self.lines.insert( 0, msg )
        if len( self.lines ) > Console.MAX_LINES:
            self.lines.pop()

    #---------------------------------------------------------------------------
    def printXY( self, msg, x, y ):
        text = self.font.render( msg, False, Console.VAR_COLOR )
        textpos = text.get_rect()
        textpos.x = x
        textpos.y = y
        self.screen.blit( text, textpos )
        
    #---------------------------------------------------------------------------
    def update( self ):
        bottom = config.HEIGHT - self.lineSize
        for line in self.lines:
            text = self.font.render( line, False, Console.COLOR )
            textpos = text.get_rect()
            textpos.x = 10
            textpos.y = bottom
            bottom -= self.lineSize
            self.screen.blit( text, textpos )

#-------------------------------------------------------------------------------
class Variable:
    MAX_VALS = 10
    
    #---------------------------------------------------------------------------
    def __init__( self, x, y, name = '', unique = False ):
        self.vals = []
        self.x = x
        self.y = y
        self.name = name
        self.unique = unique
        m_variables.append( self )
        
    #---------------------------------------------------------------------------
    def setValue( self, val ):
        self.vals.append( val )
        if len( self.vals ) > Variable.MAX_VALS:
            self.vals.pop(0)

    #---------------------------------------------------------------------------
    def getValue( self ):
        if len( self.vals ) == 0:
            return 0
        if self.unique:
            return self.vals[ len(self.vals) - 1]
        return sum( self.vals ) / float(len( self.vals ))

#-------------------------------------------------------------------------------
def init( screen ):
    m_console.init( screen )

#-------------------------------------------------------------------------------
def update():
    if not DEBUG_ENABLE:
        return;

    for v in m_variables:
        string = ''
        if v.name != '':
            string = string + v.name + ': '
        string = string + str( v.getValue() )
        m_console.printXY( string, v.x, v.y )
    m_console.update()

#-------------------------------------------------------------------------------
def printMsg( msg ):
    if DEBUG_ENABLE:
        m_console.printMsg( msg )
    else:
        print "[console]: ", msg

#-------------------------------------------------------------------------------
def nexty():
    y = m_console.m_y
    m_console.m_y += m_console.lineSize
    return y

#-------------------------------------------------------------------------------
m_console = Console()

#-------------------------------------------------------------------------------
m_variables = []

#-------------------------------------------------------------------------------
