#-------------------------------------------------------------------------------
'''Game main module.

Contains the entry point used by the run_game.py script.

Feel free to put all your game code here, or in other modules in this "gamelib"
package.
'''

#-------------------------------------------------------------------------------
import world
import pygame
import config
import debug
import bitmaps
import level
import screens
import music

#-------------------------------------------------------------------------------
def init():
    pygame.init()
    assert pygame.mixer.get_init(), "Sound failed"
    assert pygame.display.get_init(), "Display failed"
    
    screen = pygame.display.set_mode( [config.WIDTH, config.HEIGHT] )

    debug.init( screen )
    bitmaps.init()
    music.init()

#-------------------------------------------------------------------------------
def main():
    print "Pygame: ", pygame.version.ver
    init()

    music.play( "mus/music02.ogg" )
    if screens.showInitialScreen() == screens.EXIT:
        return
        
    world.resetGameData()
    running = True
    while running:
        end = screens.CONTINUE

        myWorld = world.World()
        res = myWorld.run()
        
        if res == world.World.END_GAME:
            screens.showPlayerDead()
            music.play( "mus/music02.ogg" )
            end = screens.showInitialScreen()
            world.resetGameData()
        elif res == world.World.END_LEVEL:
            world.GameData.level += 1
            if world.GameData.level >= level.maxLevels():
                music.stop()
                music.playFX( music.CHIMES )
                screens.showPlayerWin()
                music.play( "mus/music02.ogg" )
                end = screens.showInitialScreen()
                world.resetGameData()
        elif res == world.World.PLAYER_DEAD:
            music.stop()
            music.playFX( music.END )
            screens.showPlayerDead()
            music.play( "mus/music02.ogg" )
            end = screens.showInitialScreen()
            world.resetGameData()

        running = end != screens.EXIT

#-------------------------------------------------------------------------------
