#-------------------------------------------------------------------------------
import pygame
import bitmaps
import config
import debug

#-------------------------------------------------------------------------------
class Block( pygame.sprite.Sprite ):
    #---------------------------------------------------------------------------
    def __init__( self, x, y ):
        self.typename = 'Block'
        pygame.sprite.Sprite.__init__( self )
        self.image = pygame.Surface((32,64)).convert()
        self.image.fill( config.COLOR_KEY )
        self.rect = self.image.get_rect().move( 96 + 32*x, 32*(y-1) )

        objects = bitmaps.get( 'obj01' )
        dst = (0,0,32,32)
        src = (2*32,0,32,32)
        self.image.blit( objects, dst, src )
        dst = (0,32,32,32)
        src = (1*32,0,32,32)
        self.image.blit( objects, dst, src )
        self.image.set_colorkey( config.COLOR_KEY )

        self.hookPoint = pygame.Rect( 
            96 + 32*x + 2, 32*y + 2, 28, 28 )

        self.ended = False

    #---------------------------------------------------------------------------
    def isZombie( self ):
        return self.ended

    #---------------------------------------------------------------------------
    def isHookable( self ):
        return True

    #---------------------------------------------------------------------------
    def getHookPoint( self ):
        return self.hookPoint        

    #---------------------------------------------------------------------------
    def destroy( self ):
        self.ended = True

    #---------------------------------------------------------------------------
    def move( self, inc ):
        self.hookPoint = self.hookPoint.move( inc )
        self.rect = self.rect.move( inc )

    #---------------------------------------------------------------------------
    def checkCollision( self, spr, rect ):
        mycollisionRect = self.rect
        if rect.colliderect( mycollisionRect ):
            return True
        return False

#-------------------------------------------------------------------------------
class ExitDoor( pygame.sprite.Sprite ):
    #---------------------------------------------------------------------------
    def __init__( self, x, y ):
        self.typename = 'ExitDoor'
        pygame.sprite.Sprite.__init__( self )
        self.image = pygame.Surface((32,32)).convert()
        self.image.fill( config.COLOR_KEY )
        self.rect = self.image.get_rect().move( 96 + 32*x, 32*y )

        objects = bitmaps.get( 'obj01' )
        dst = (0,0,32,32)
        src = (0,0,32,32)
        self.image.blit( objects, dst, src )
        self.image.set_colorkey( config.COLOR_KEY )

    #---------------------------------------------------------------------------
    def isZombie( self ):
        return False

    #---------------------------------------------------------------------------
    def isHookable( self ):
        return False

    #---------------------------------------------------------------------------
    def checkCollision( self, spr, rect ):
        mycollisionRect = self.rect.inflate( 0, -16 )
        if rect.colliderect( mycollisionRect ):
            spr.exitLevel()
            return True
        return False

#-------------------------------------------------------------------------------
class String( pygame.sprite.Sprite ):
    #---------------------------------------------------------------------------
    def __init__( self, point1, point2 ):
        self.typename = 'String'
        pygame.sprite.Sprite.__init__( self )

        if point1[0] == point2[0]:
            if point1[1] > point2[1]:
                temp = point1
                point1 = point2
                point2 = temp
            real_w = 32
            real_h = point2[1] - point1[1] - 16

            real_x = point1[0]
            real_y = point1[1] + 32
            stringBmp = bitmaps.get( 'stringV' )
        else:
            if point1[0] > point2[0]:
                temp = point1
                point1 = point2
                point2 = temp
            real_w = point2[0] - point1[0] - 16
            real_h = 32

            real_x = point1[0] + 16 
            real_y = point1[1]
            stringBmp = bitmaps.get( 'stringH' )

        if real_x < 16:
            real_x = 16
        if real_y < 16:
            real_y = 16
        self.image = pygame.Surface((real_w,real_h)).convert()
        self.image.fill( config.COLOR_KEY )
        self.rect = self.image.get_rect().move( real_x, real_y )
        self.image.blit( stringBmp, self.image.get_rect() )
        self.image.set_colorkey( config.COLOR_KEY )

        self.ended = False

    #---------------------------------------------------------------------------
    def isZombie( self ):
        return self.ended

    #---------------------------------------------------------------------------
    def isHookable( self ):
        return False

    #---------------------------------------------------------------------------
    def destroy( self ):
        self.ended = True

    #---------------------------------------------------------------------------
    def move( self, inc ):
        self.rect = self.rect.move( inc )

    #---------------------------------------------------------------------------
    def checkCollision( self, spr, rect ):
        return False

#-------------------------------------------------------------------------------
class StringBridge( pygame.sprite.Sprite ):
    MAX_LIFE = 5 * config.FPS
    #---------------------------------------------------------------------------
    def __init__( self, log1, log2, level ):
        self.typename = 'StringBridge'
        pygame.sprite.Sprite.__init__( self )
        self.logs = [ log1, log2 ]
        self.logs[0].isUsed = True
        self.logs[1].isUsed = True

        point1 = self.logs[0].getHookPoint().center
        point2 = self.logs[1].getHookPoint().center
        if point1[0] == point2[0]:
            if point1[1] > point2[1]:
                temp = point1
                point1 = point2
                point2 = temp
            real_w = 32
            real_h = point2[1] - point1[1]

            real_x = point1[0] - 16
            real_y = point1[1]
            self.vertical = True
            stringBmp = bitmaps.get( 'stringV' )
        else:
            if point1[0] > point2[0]:
                temp = point1
                point1 = point2
                point2 = temp
            real_w = point2[0] - point1[0]
            real_h = 32

            real_x = point1[0]
            real_y = point1[1] - 16
            self.vertical = False
            stringBmp = bitmaps.get( 'stringH' )

        self.image = pygame.Surface((real_w,real_h)).convert()
        self.image.fill( config.COLOR_KEY )
        self.rect = self.image.get_rect().move( real_x, real_y )
        self.image.blit( stringBmp, self.image.get_rect() )
        self.image.set_colorkey( config.COLOR_KEY )
        
        self.level = level
        self.bridgeTiles = self.level.addBridge( point1, point2 )

        self.life = 0
        self.ended = False
        self.next_update_time = 0
        
    #---------------------------------------------------------------------------
    def isZombie( self ):
        return self.ended

    #---------------------------------------------------------------------------
    def isHookable( self ):
        return False

    #---------------------------------------------------------------------------
    def checkCollision( self, spr, rect ):
        return False

    #---------------------------------------------------------------------------
    def update( self, current ):
        if self.next_update_time < current:
            if not self.ended:
                self.life += 1
            
                if self.life == StringBridge.MAX_LIFE:
                    if self.vertical:
                        stringBmp = bitmaps.get( 'stringBurnedV' )
                    else:
                        stringBmp = bitmaps.get( 'stringBurnedH' )
                    self.image.fill( config.COLOR_KEY )
                    self.image.blit( stringBmp, self.image.get_rect() )
                elif self.life > (StringBridge.MAX_LIFE + 5):
                    debug.printMsg( "Bridge burned" )
                    self.ended = True
                    self.logs[0].isUsed = False
                    self.logs[1].isUsed = False
                    self.level.removeTiles( self.bridgeTiles )

            self.next_update_time = current + config.TIME_STEP
        
#-------------------------------------------------------------------------------
class SwingStringV( pygame.sprite.Sprite ):
    #---------------------------------------------------------------------------
    def __init__( self ):
        self.typename = 'SwingStringV'
        pygame.sprite.Sprite.__init__( self )

        self.image = pygame.Surface((32,32)).convert()
        self.image.fill( config.COLOR_KEY )
        self.rect = self.image.get_rect().move( 100, 100 )
        self.image.set_colorkey( config.COLOR_KEY )

        self.ended = False

    #---------------------------------------------------------------------------
    def isZombie( self ):
        return self.ended

    #---------------------------------------------------------------------------
    def isHookable( self ):
        return False

    #---------------------------------------------------------------------------
    def destroy( self ):
        self.ended = True

    #---------------------------------------------------------------------------
    def setSize( self, x0, x1, y ):
        final_x0 = min( x0, x1 )
        final_x1 = max( x0, x1 )
        self.image = pygame.Surface((final_x1 - final_x0,32)).convert()
        self.rect = self.image.get_rect().move( final_x0, y )
        self.image.fill( config.COLOR_KEY )
        self.image.blit( bitmaps.get( 'stringH' ), self.image.get_rect() )
        self.image.set_colorkey( config.COLOR_KEY )

#-------------------------------------------------------------------------------
class SwingStringH( pygame.sprite.Sprite ):
    #---------------------------------------------------------------------------
    def __init__( self ):
        self.typename = 'SwingStringV'
        pygame.sprite.Sprite.__init__( self )

        self.image = pygame.Surface((32,32)).convert()
        self.image.fill( config.COLOR_KEY )
        self.rect = self.image.get_rect().move( 100, 100 )
        self.image.set_colorkey( config.COLOR_KEY )

        self.ended = False

    #---------------------------------------------------------------------------
    def isZombie( self ):
        return self.ended

    #---------------------------------------------------------------------------
    def isHookable( self ):
        return False

    #---------------------------------------------------------------------------
    def destroy( self ):
        self.ended = True

    #---------------------------------------------------------------------------
    def setSize( self, y0, y1, x ):
        final_y0 = min( y0, y1 )
        final_y1 = max( y0, y1 )
        self.image = pygame.Surface((32,final_y1 - final_y0)).convert()
        self.rect = self.image.get_rect().move( x, final_y0 )
        self.image.fill( config.COLOR_KEY )
        self.image.blit( bitmaps.get( 'stringV' ), self.image.get_rect() )
        self.image.set_colorkey( config.COLOR_KEY )

#-------------------------------------------------------------------------------
