#-------------------------------------------------------------------------------
import pygame
import debug
import config
import bitmaps
from pygame.locals import *

#-------------------------------------------------------------------------------
EXIT = 0
CONTINUE = 1

#-------------------------------------------------------------------------------
class StaticScreen:
    #---------------------------------------------------------------------------
    def __init__( self ):
        self.screen = pygame.display.get_surface()
        self.font = pygame.font.SysFont( 'Monospace', 40 )
        self.font2 = pygame.font.SysFont( 'Monospace', 24 )
        self.font3 = pygame.font.SysFont( 'Monospace', 16 )

    #---------------------------------------------------------------------------
    def run( self ):
        pygame.display.update()

        running = True
        while running:
            init_tick = pygame.time.get_ticks()

            events = pygame.event.get()
            for event in events:
                if event.type == QUIT:
                    self.exitCode = EXIT
                    running = False
                elif event.type == KEYDOWN:
                    if event.key == K_ESCAPE:
                        self.exitCode = EXIT
                        running = False
                    elif event.key == K_RETURN:
                        self.exitCode = CONTINUE
                        running = False

            end_tick = pygame.time.get_ticks()
            diff_tick = end_tick - init_tick
            if diff_tick < config.TIME_STEP:
                pygame.time.delay( diff_tick )
            else:
                debug.printMsg( 
                    "frame too slow " + str( diff_tick ) 
                    + " " + str( config.TIME_STEP ) )
                
    #---------------------------------------------------------------------------
    def clear( self, color ):
        self.screen.fill( color )

    #---------------------------------------------------------------------------
    def __printMsg( self, font, x, y, msg ):
        text = font.render( msg, False, [255,255,255] )
        textpos = text.get_rect()
        textpos.x = x
        textpos.y = y
        self.screen.blit( text, textpos )        

    #---------------------------------------------------------------------------
    def printMsg( self, x, y, msg ):
        self.__printMsg( self.font, x, y, msg )

    #---------------------------------------------------------------------------
    def printMsg2( self, x, y, msg ):
        self.__printMsg( self.font2, x, y, msg )

    #---------------------------------------------------------------------------
    def printMsg3( self, x, y, msg ):
        self.__printMsg( self.font3, x, y, msg )

#-------------------------------------------------------------------------------
def showPlayerWin():
    screen = StaticScreen()
    screen.clear( [0,50,0] )
    objs = bitmaps.get( 'obj01' )
    dst = ( (config.WIDTH/2) - (96/2), 150, 96, 96 )
    src = ( 7*32, 32, 96, 96 )
    screen.screen.blit( objs, dst, src )
    screen.printMsg( 250, 250, "You WIN!!!" )
    screen.printMsg2( 220, 300, "Press <enter> to continue" )
    screen.run()

#-------------------------------------------------------------------------------
def showPlayerDead():
    screen = StaticScreen()
    screen.clear( [50,0,0] )
    objs = bitmaps.get( 'obj01' )
    dst = ( (config.WIDTH/2) - (96/2), 150, 96, 96 )
    src = ( 4*32, 32, 96, 96 )
    screen.screen.blit( objs, dst, src )
    screen.printMsg( 240, 250, "You LOST!!!" )
    screen.printMsg2( 220, 300, "Press <enter> to continue" )
    screen.run()

#-------------------------------------------------------------------------------
def showInitialScreen():
    screen = StaticScreen()
    screen.clear( [0,0,50] )
    objs = bitmaps.get( 'obj01' )
    dst = ( (config.WIDTH/2) - (96/2), 100, 96, 96 )
    src = ( 1*32, 32, 96, 96 )
    screen.screen.blit( objs, dst, src )
    screen.printMsg( 200, 20, "SHOT THE HOOK" )
    screen.printMsg2( 210, 50, "by Luis Cabellos" )
    screen.printMsg3( 200, 250, "HOW TO PLAY THE GAME:" )
    screen.printMsg3( 200, 270, 
                      "* Use the arrow keys to move the player" )
    screen.printMsg3( 200, 285, 
                      "* Press spacebar to launch the string+hook" )
    screen.printMsg3( 200, 300, 
                      "* You have limited amount of string" )
    screen.printMsg3( 200, 315, 
                      "* Don't leave the tiles... and go to the exit door" )
    screen.printMsg2( 220, 420, "Press <enter> to continue" )
    screen.printMsg2( 245, 440, "Press <esc> to exit" )

    player = bitmaps.get( 'player' )
    for i in range(0,12):
        dst = ( 145, i*40, 32, 32 )
        src = ( 0, (i%4)*32, 32, 32 )
        screen.screen.blit( player, dst, src )
        dst = ( config.WIDTH - (32 + 145), i*40, 32, 32 )
        src = ( 0, (i%4)*32, 32, 32 )
        screen.screen.blit( player, dst, src )
    screen.run()

    return screen.exitCode

#-------------------------------------------------------------------------------
